==> dl.php?src=linea21_1_8.zip: linea21/sdi/menurub.php <==
<?php
/**
 * indicators /SDI module
 * 
 * Set-up module related menu in back-office
 * 
 * @package linea21\modules\sdi
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

$rub_link_add=$rub_link."&amp;todo=add";
$rub_link_list=$rub_link."&amp;todo=list";
$rub_link_mod=$rub_link."&amp;todo=mod";
$rub_link_det=$rub_link."&amp;todo=det";
$rub_link_sup=$rub_link."&amp;todo=sup";

$search="search.php?rub=".$rub;
if($todo=='add') $title=_t('sdi','add');
if($todo=='list') $title=_t('sdi','list');

if($todo=='mod') $title=_t('sdi','mod');
if($todo=='mod_r') $title=_t('sdi','mod_r');
if($todo=='mod_e') $title=_t('sdi','mod_e');
if($todo=='mod_p') $title=_t('sdi','mod_p');

if($todo=='sup') $title=_t('sdi','sup');
if($todo=='det') $title=_t('sdi','det');
?>
<div id="itemenu">
	<h1><?php echo $title; ?></h1>
	<div class="contentlink">
		<?php $dispatcher->notify(new sfEvent('secondary_menu', 'admin_sdi.menu_start'));?>
		<a href="<?php echo $rub_link_add; ?>" title="<?php echo _t('sdi','add');?>"><i class="icon-plus"></i><?php echo _t('sdi','add');?></a>
		| <a href="<?php echo $rub_link_list; ?>" title="<?php echo _t('sdi','list');?>"><i class="icon-list"></i><?php echo _t('sdi','list');?></a>
		| <a href="<?php echo $search; ?>" title="<?php echo _t('menu','search');?>"><i class="icon-search"></i><?php echo _t('menu','search');?></a>
		<?php $dispatcher->notify(new sfEvent('secondary_menu', 'admin_sdi.menu_end'));?>
	</div>
</div>

==> dl.php?src=linea21_2_3_0.zip: linea21/sdi/menurub.php <==
<?php
/**
 * indicators /SDI module
 * 
 * Set-up module related menu in back-office
 * 
 * @package linea21\modules\sdi
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

$rub_link_add=$rub_link."&amp;todo=add";
$rub_link_list=$rub_link."&amp;todo=list";
$rub_link_mod=$rub_link."&amp;todo=mod";
$rub_link_det=$rub_link."&amp;todo=det";
$rub_link_sup=$rub_link."&amp;todo=sup";

$search="search.php?rub=".$rub;
if($todo=='add') $title=_t('sdi','add');
if($todo=='list') $title=_t('sdi','list');

if($todo=='mod') $title=_t('sdi','mod');
if($todo=='mod_r') $title=_t('sdi','mod_r');
if($todo=='mod_e') $title=_t('sdi','mod_e');
if($todo=='mod_p') $title=_t('sdi','mod_p');

if($todo=='sup') $title=_t('sdi','sup');
if($todo=='det') $title=_t('sdi','det');
?>
<div id="itemenu">
	<h1><?php echo $title; ?></h1>
	<div class="contentlink">
		<?php $dispatcher->notify(new sfEvent('secondary_menu', 'admin_sdi.menu_start'));?>
		<a href="<?php echo $rub_link_add; ?>" title="<?php echo _t('sdi','add');?>"><i class="icon-plus"></i><?php echo _t('sdi','add');?></a>
		<a href="<?php echo $rub_link_list; ?>" title="<?php echo _t('sdi','list');?>"><i class="icon-list"></i><?php echo _t('sdi','list');?></a>
		<a href="<?php echo $search; ?>" title="<?php echo _t('menu','search');?>"><i class="icon-search"></i><?php echo _t('menu','search');?></a>
		<?php $dispatcher->notify(new sfEvent('secondary_menu', 'admin_sdi.menu_end'));?>
	</div>
</div>
